/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.util.config.Property;


/**
 * <p>
 * Defines a concrete implementation of <code>FileMatcher</code> to provide the functionality to match text files.
 * There is no configuration for this class. However, in order to be used by <code>FileProcessor</code>
 * implementations, an empty constructor with <code>Property</code> argument is available.
 * </p>
 *
 * <p>
 * This class is thread-safe, since it is stateless.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class TextFileMatcher extends FileCategoryMatcher {
    /**
     * <p>
     * Creates a new instance of <code>TextFileMatcher</code> class.
     * </p>
     */
    public TextFileMatcher() {
    }

    /**
     * <p>
     * Creates a new instance of <code>TextFileMatcher</code> class. This class does not require any configuration.
     * </p>
     *
     * @param property the property where configurations are read from.
     *
     * @throws NullPointerException if <code>property</code> is <code>null</code>.
     */
    public TextFileMatcher(Property property) {
        Validator.validateNotNull(property, "property");
    }

    /**
     * <p>
     * Gets a flag indicating whether the binary file flag is <code>false</code>.
     * </p>
     *
     * @param isBinary a flag indicating whether the file is binary.
     *
     * @return <code>true</code> if the given binary file flag is <code>false</code>; <code>false</code> otherwise.
     */
    protected boolean match(boolean isBinary) {
        return !isBinary;
    }
}



