/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.Assert;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.StringReader;


/**
 * <p>
 * Defines a helper class used in tests.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public final class TestHelper {
    /**
     * <p>
     * Creates a new instance of <code>TestHelper</code> class. This private constructor prevents from creating a
     * new instance of this class.
     * </p>
     */
    private TestHelper() {
    }

    /**
     * <p>
     * Asserts that the given string should be the same as the content of the given file.
     * </p>
     *
     * @param error the error message if assertion fails.
     * @param expected the expected string storing in a text file.
     * @param actual the actual string.
     */
    public static void assertEquals(String error, File expected, String actual) {
        BufferedReader reader = null;
        BufferedReader actualReader = new BufferedReader(new StringReader(actual));
        String line;

        try {
            reader = new BufferedReader(new FileReader(expected));

            // Read every line and compare the content.
            while ((line = reader.readLine()) != null) {
                // The '/' and '\\' are replaced by '|' to solve the problem of different platform.
                // '|' is never used in reports, so it will not cause problems.
                line = line.replace('/', '|').replace('\\', '|');
                Assert.assertEquals(error, line, actualReader.readLine().replace('/', '|').replace('\\', '|'));
            }

            // The actual string should be empty as well.
            Assert.assertNull(error, actualReader.readLine());
        } catch (IOException e) {
            Assert.fail(error);
        } finally {
            if (reader != null) {
                try {
                    reader.close();
                    actualReader.close();
                } catch (IOException e) {
                    // ignore
                }
            }
        }
    }
}



