/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * <p>
 * Tests functionality and error cases of <code>BinaryFileMatcher</code> class. The constructors are trivil, so the
 * accuracy tests are omitted. The <code>match(File)</code> method is defined in its super class
 * <code>FileCategoryMatcher</code>. The accuracy and error cases of this method is already tested in the test case
 * of that class. Therefore, here only the protected <code>match</code> method is tested.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class BinaryFileMatcherTestCase extends TestCase {
    /** Represents the <code>BinaryFileMatcher</code> instance used in tests. */
    private BinaryFileMatcher matcher;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     */
    protected void setUp() {
        matcher = new BinaryFileMatcher();
    }

    /**
     * <p>
     * Cleans up the test environment. The test instance is disposed.
     * </p>
     */
    protected void tearDown() {
        matcher = null;
    }

    /**
     * <p>
     * Tests constructor <code>BinaryFileMatcher(Property)</code> when the given property is <code>null</code>.
     * Expect NullPointerException.
     * </p>
     */
    public void testBinaryFileMatcherPropertyNull() {
        try {
            new BinaryFileMatcher(null);
            fail("The property is null, should throw NullPointerException.");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests accuracy of <code>match(boolean)</code>. The matcher should return the given argument directly.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchAccuracy() throws Exception {
        assertTrue("When file binary flag is true, it matches the binary file.", matcher.match(true));
        assertFalse("When file binary flag is false, it does not match the text file.", matcher.match(false));
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(BinaryFileMatcherTestCase.class);
    }
}



