/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.reporting;

import com.topcoder.file.statistics.Metric;
import com.topcoder.file.statistics.StatsReporting;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.TestHelper;
import com.topcoder.file.statistics.matcher.AnyFileMatcher;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounter;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * <p>
 * Tests functionality and error cases of <code>BasicStatsReporting</code> class. Since the constructors of this
 * class soly delegate the super class' constructors, the tests of constructors are not needed.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class BasicStatsReportingTestCase extends TestCase {
    /** Represents the <code>BasicStatsReporting</code> instance used in tests. */
    private StatsReporting reporting;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    protected void setUp() throws Exception {
        reporting = new BasicStatsReporting();
    }

    /**
     * <p>
     * Cleans up the test environment. The test instance is disposed.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    protected void tearDown() throws Exception {
        reporting = null;
    }

    /**
     * <p>
     * Tests accuracy of <code>generateReport</code>. The content of the report should contain all statistical
     * results including results for files, directories, processors and the overall result. Since there is no
     * specific format in component specification, the test case verifies the format provided by the developer.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testGenerateReportAccuracy() throws Exception {
        // Aggregate three results
        StatsResult result = new StatsResult();

        result.setStat(new Metric("metric1", "display metric1", "description1"), 100);
        reporting.aggregate(new TextLineCounter("processor1", new AnyFileMatcher()), new File("test_files/filea"),
            result);

        result = new StatsResult();
        result.setStat(new Metric("metric2", "display metric2", "description2"), 2);
        reporting.aggregate(new TextLineCounter("processor2", new AnyFileMatcher()), new File("conf/fileb"), result);

        result = new StatsResult();
        result.setStat(new Metric("metric2", "display metric2", "description2"), 3);
        reporting.aggregate(new TextLineCounter("processor2", new AnyFileMatcher()), new File("conf/filec"), result);

        // Generate the report
        String report = reporting.generateReport();

        // Verify the report
        TestHelper.assertEquals("The generated report should be correct.", new File("test_files/TextReport.txt"),
            report);
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(BasicStatsReportingTestCase.class);
    }
}



