/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * <p>
 * Tests functionality of custom exceptions. All consturctors are tested.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 1.0
 */
public class ExceptionTestCase extends TestCase {
    /**
     * <p>
     * Represents a string with a detail message.
     * </p>
     */
    private static final String DETAIL_MESSAGE = "detail";

    /**
     * <p>
     * Represents a throwable cause.
     * </p>
     */
    private static final Exception CAUSE = new Exception();

    /**
     * <p>
     * Tests accuracy of <code>FileStatisticsException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     */
    public void testFileStatisticsExceptionStringAccuracy() {
        //Construct FileStatisticsException with a detail message
        FileStatisticsException exception = new FileStatisticsException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>FileStatisticsException(String, Throwable)</code> constructor. The detail error
     * message and the original cause of error should be correct.
     * </p>
     */
    public void testFileStatisticsExceptionStringThrowableAccuracy() {
        //Construct FileStatisticsException with a detail message and a cause
        FileStatisticsException exception = new FileStatisticsException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>ConfigurationException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     */
    public void testConfigurationExceptionStringAccuracy() {
        //Construct ConfigurationException with a detail message
        ConfigurationException exception = new ConfigurationException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>ConfigurationException(String, Throwable)</code> constructor. The detail error message
     * and the original cause of error should be correct.
     * </p>
     */
    public void testConfigurationExceptionStringThrowableAccuracy() {
        //Construct ConfigurationException with a detail message and a cause
        ConfigurationException exception = new ConfigurationException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>FileMatchingException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     */
    public void testFileMatchingExceptionStringAccuracy() {
        //Construct FileMatchingException with a detail message
        FileMatchingException exception = new FileMatchingException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>FileMatchingException(String, Throwable)</code> constructor. The detail error message
     * and the original cause of error should be correct.
     * </p>
     */
    public void testFileMatchingExceptionStringThrowableAccuracy() {
        //Construct FileMatchingException with a detail message and a cause
        FileMatchingException exception = new FileMatchingException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>FileProcessingException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     */
    public void testFileProcessingExceptionStringAccuracy() {
        //Construct FileProcessingException with a detail message
        FileProcessingException exception = new FileProcessingException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>FileProcessingException(String, Throwable)</code> constructor. The detail error
     * message and the original cause of error should be correct.
     * </p>
     */
    public void testFileProcessingExceptionStringThrowableAccuracy() {
        //Construct FileProcessingException with a detail message and a cause
        FileProcessingException exception = new FileProcessingException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>StatsReportingException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     */
    public void testStatsReportingExceptionStringAccuracy() {
        //Construct StatsReportingException with a detail message
        StatsReportingException exception = new StatsReportingException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>StatsReportingException(String, Throwable)</code> constructor. The detail error
     * message and the original cause of error should be correct.
     * </p>
     */
    public void testStatsReportingExceptionStringThrowableAccuracy() {
        //Construct StatsReportingException with a detail message and a cause
        StatsReportingException exception = new StatsReportingException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>InvalidArgumentException(String)</code> constructor. The detail error message should be
     * correct.
     * </p>
     *
     * @since 2.0b
     */
    public void testInvalidArgumentExceptionStringAccuracy() {
        //Construct InvalidArgumentException with a detail message
        InvalidArgumentException exception = new InvalidArgumentException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Tests accuracy of <code>InvalidArgumentException(String, Throwable)</code> constructor. The detail error
     * message and the original cause of error should be correct.
     * </p>
     *
     * @since 2.0b
     */
    public void testInvalidArgumentExceptionStringThrowableAccuracy() {
        //Construct InvalidArgumentException with a detail message and a cause
        InvalidArgumentException exception = new InvalidArgumentException(DETAIL_MESSAGE, CAUSE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message with cause should be correct.", DETAIL_MESSAGE, exception.getMessage());

        //Verify that there is a cause
        assertNotNull("Should have cause.", exception.getCause());
        assertTrue("Cause should be identical.", CAUSE == exception.getCause());
    }

    /**
     * <p>
     * Tests accuracy of <code>MissingInitializationException(String)</code> constructor. The detail error message
     * should be correct.
     * </p>
     *
     * @since 2.0b
     */
    public void testMissingInitializationExceptionStringAccuracy() {
        //Construct MissingInitializationException with a detail message
        MissingInitializationException exception = new MissingInitializationException(DETAIL_MESSAGE);

        //Verify that there is a detail message
        assertNotNull("Should have message.", exception.getMessage());
        assertEquals("Detailed error message should be identical.", DETAIL_MESSAGE, exception.getMessage());
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(ExceptionTestCase.class);
    }
}




