/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.processor;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.file.statistics.FileProcessingException;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.processor.FileProcessorBase;
import com.topcoder.util.config.Property;

/**
 * <p>
 * Mock implementation of FileProcessorBase, used for test purposes.
 * </p>
 *
 * @author cucu
 * @version 1.0
 */

public class MockProcessor extends FileProcessorBase {

    /**
     * This constructor loads configuration from the property. It Just calls the base constructor.
     *
     * @param property the property to load config from
     *
     * @throws ConfigurationException if config error occurs
     */
    protected MockProcessor(Property property) throws ConfigurationException {
        super(property);
    }

    /**
     * <p>
     * Constructor with both alias and matcher. It Just calls the base constructor.
     * </p>
     *
     * @param alias the alias
     * @param matcher the file matcher
     */
    protected MockProcessor(String alias, FileMatcher matcher) {
        super(alias, matcher);
    }

    /**
     * Just returns an empty list
     */
    public List getSupportedMetrics() {
        return new ArrayList();
    }

   /**
    * Mock processing of the file.  Just returns an empty StatsResult
    *
    * @param file not used
    */
    public StatsResult process(File file) throws IOException,
            FileProcessingException {
        return new StatsResult();
    }

}
