/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.reporting;

import junit.framework.TestCase;

import com.topcoder.file.statistics.Metric;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.reporting.StatsCollection;


/**
 * <p>
 * Accuracy tests for StatsCollection.
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class StatsCollectionAccuracyTests extends TestCase {

    /**
     *  StatsResult used for testing.  Values will be set in set up.
     */
    private StatsResult sr1 = null;

    /**
     *  StatsResult used for testing.  Values will be set in set up.
     */
    private StatsResult sr2 = null;

    /**
     *  Metric used for testing.
     */
    private Metric m = new Metric("test", "test", "test");


    /**
     *  The StatsCollection object to be tested.
     */
    private StatsCollection sc = null;

    /**
     *  Set up for each test.
     */
    public void setUp()  {
        sr1 = new StatsResult();
        sr2 = new StatsResult();
        sc = new StatsCollection();

        // set metric values for the results.
        sr1.setStat(m, 1);
        sr2.setStat(m, 2);
    }

    /**
     * Test that the constructor creates an empty set.
     */
    public void testConstructor()  {
        assertEquals("StatsCollection should be created without any StatsResult", 0, sc.getAllKeys().size());
    }


   /**
     *  Test the add method to verify that it adds results and that it makes a copy of the inserted object.
     */
    public void testAdd()  {
        sc.add("sr1", sr1);
        sc.add("sr2", sr2);


        assertEquals("StatsCollection should have 2 elements", 2, sc.getAllKeys().size());
        assertEquals("bad balue retrieved for sr1", sr1.getStat(m), sc.get("sr1").getStat(m));
        assertEquals("bad balue retrieved for sr2", sr2.getStat(m), sc.get("sr2").getStat(m));

        sr1.aggregate(sr2);

        assertEquals("Add method is not making a copy", 1, sc.get("sr1").getStat(m));
    }

    /**
     * Test that the add method aggregates results
     */
    public void testAddAggregate()  {
        sc.add("result1", sr1);
        sc.add("result1", sr1);
        sc.add("result1", sr1);
        sc.add("result1", sr1);
        sc.add("result1", sr1);

        sc.add("result2", sr2);

        assertEquals("StatsCollection should have 2 elements", 2, sc.getAllKeys().size());

        assertEquals("bad balue retrieved for result1", sr1.getStat(m) * 5, sc.get("result1").getStat(m));
        assertEquals("bad balue retrieved for result2", sr2.getStat(m), sc.get("result2").getStat(m));

    }

    /**
     * Test that the getAllKey method returns a sorted case insensitive list of keys.
     */
    public void testGetAllKey()  {
        sc.add("a", sr1);
        sc.add("B", sr2);

        assertEquals("bad key value", "a", sc.getAllKeys().get(0));
        assertEquals("bad key value", "B", sc.getAllKeys().get(1));
    }



    /**
     * Thet that the get methods retrieves the right value and that it makes a copy.
     */
    public void testGet()  {
        sc.add("sr1", sr1);
        sc.add("sr2", sr2);

        assertEquals("bad balue retrieved for sr1", sr1.getStat(m), sc.get("sr1").getStat(m));
        assertNull("get method must return null if the key was not found", sc.get("non-existent"));

        // Test that the get makes a copy
        StatsResult srCopy = sc.get("sr1");
        srCopy.aggregate(sr2);
        assertEquals("get is not returning a copy of the object", 1, sc.get("sr1").getStat(m));
    }


    /**
     *  Test the clear method
     */
    public void testClear() {
        sc.add("sr1", sr1);

        sc.clear();
        assertEquals("Clear should erase all the elements", 0, sc.getAllKeys().size());
    }



}
