/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.reporting;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.accuracytests.TestHelper;
import com.topcoder.file.statistics.matcher.AnyFileMatcher;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounter;
import com.topcoder.file.statistics.reporting.XmlStatsReporting;


/**
 * <p>
 * Accuracy tests for XmlStatsReporting
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class XmlStatsReportingAccuracyTests extends TestCase {

    /**
     *  Test creating an empty report and saving it so it can be visually inspected.
     */
    public void testEmptyReport() throws Exception {
        XmlStatsReporting xmlsr = new XmlStatsReporting();
        createReport(xmlsr, new String[]{}, "test_files/AccuracyTests/ReportResults/EmptyReport.xml");
    }

    /**
     * Test creating a report of a file and saving it so it can be visually inspected.
     */
    public void testReport1() throws Exception {
        XmlStatsReporting xmlsr = new XmlStatsReporting();
        createReport(xmlsr, new String[]{TestHelper.CS_FILE}, "test_files/AccuracyTests/ReportResults/Report1.xml");
    }

    /**
     * Test creating a report of some files and saving it so it can be visually inspected.
     */
    public void testReport2() throws Exception {
        XmlStatsReporting xmlsr = new XmlStatsReporting();
        createReport(xmlsr, new String[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR}
                , "test_files/AccuracyTests/ReportResults/Report2.xml");
    }

    /**
     * Test doing a reset to have a base directory.
     */
    public void testReset() throws Exception {
        XmlStatsReporting xmlsr = new XmlStatsReporting();
        xmlsr.reset(new File("test_files/AccuracyTests/files/"));

        createReport(xmlsr, new String[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR},
            "test_files/AccuracyTests/ReportResults/Reset.xml");
    }

    /**
     *  Test Stylesheet
     */
    public void testStylesheet() throws Exception {
        XmlStatsReporting bsr = new XmlStatsReporting(new File("test_files/reporting.xsl"));

        createReport(bsr, new String[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR},
            "test_files/AccuracyTests/ReportResults/ReportingWithStylesheet.html");
    }


    /**
     * Creata a report with XmlStatsReporting and outputs it to a file
     *
     * @param xmlsr XmlStatsReporting to generate
     * @param files files to be processed
     * @param outputFileName name of the file where the report is written
     * @throws Exception
     */
    private void createReport(XmlStatsReporting xmlsr, String []files, String outputFileName) throws Exception {

        FileProcessor fp = new CStyleLineCounter("Source File", new AnyFileMatcher());

        for (int i = 0; i < files.length; i++) {

            StatsResult sr = new StatsResult();
            File fi = new File(files[i]);
            sr.aggregate(fp.process(fi));
            xmlsr.aggregate(fp, fi, sr);
        }
        BufferedWriter out = new BufferedWriter(new FileWriter(outputFileName));
        out.write(xmlsr.generateReport());
        out.close();
    }

}
