/*
 * $(#)CStyleLineCounterTests.java        Sep 6, 2005
 *
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.processor.linecounter;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.matcher.ExtensionMatcher;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounter;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;

/**
 * This test case contains the failure tests for the <code>CStyleLineCounter</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class CStyleLineCounterTests extends TestCase {

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.processor.linecounter.failuretests";

    /**
     * The config file for this test.
     */
    private static final String CONFIG_FILE = "failuretests/processor/config.xml";

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/failuretests/processor/";

    /**
     * An CStyleLineCounter instance to test.
     */
    private CStyleLineCounter counter = null;

    /**
     * Load the configuration before testing.
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        counter = new CStyleLineCounter("Text", new ExtensionMatcher("txt"));
    }

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception in case anything goes wrong
     */
    protected void tearDown() throws Exception {
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
     * NullPointerException for null argument.
     */
    public void testCStyleLineCounter1() {
        try {
            new CStyleLineCounter(null, new ExtensionMatcher("txt"));
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
     * NullPointerException for null argument.
     */
    public void testCStyleLineCounter2() {
        try {
            new CStyleLineCounter("alias", null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(String, FileMatcher) properly throws
     * IllegalArgumentException for empty String argument.
     */
    public void testCStyleLineCounter3() {
        try {
            new CStyleLineCounter(" ", new ExtensionMatcher("txt"));
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter4() throws Exception {
        try {
            new CStyleLineCounter((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter5() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid1");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter6() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid2");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter7() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid3");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter8() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid5");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter9() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid6");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter10() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid7");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter11() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid8");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor CStyleLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testCStyleLineCounter12() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid9");

        try {
            new CStyleLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Tests the process method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException in case anything goes wrong
     */
    public void testProcess1() throws IOException {
        try {
            counter.process(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Tests the process method with a folder as argument. IOException should be thrown.
     */
    public void testProcess2() {
        try {
            counter.process(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * Tests the process method with invalid argument. IOException should be thrown.
     */
    public void testProcess3() {
        try {
            counter.process(new File(BASE_PATH, "inexistent_file"));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

}
