/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.FileMatchingException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * <p>
 * Tests functionality and error cases of <code>FileNameMatcher</code> class. Since it is an abstract class, a mock
 * concrete implementation <code>MockFileNameMatcher</code> is used.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 1.0
 */
public class FileNameMatcherTestCase extends TestCase {
    /** Represents the <code>FileNameMatcher</code> instance used in tests. */
    private MockFileNameMatcher matcher;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     */
    protected void setUp() {
        matcher = new MockFileNameMatcher();
    }

    /**
     * <p>
     * Cleans up the test environment. The test instance is disposed.
     * </p>
     */
    protected void tearDown() {
        matcher = null;
    }

    /**
     * <p>
     * Tests <code>match</code> when the given file is <code>null</code>. Expect NullPointerException.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchNull() throws Exception {
        try {
            matcher.match((File) null);
            fail("The file is null, should throw NullPointerException.");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests <code>match</code> when error occurs when matching the file name. Expect FileMatchingException.
     * </p>
     */
    public void testMatchError() {
        try {
            matcher.match(new File("error"));
            fail("Error occurs when matching the file name, should throw FileMatchingException.");
        } catch (FileMatchingException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests accuracy of <code>match</code>. The protected method <code>match</code> should receive the file name as
     * argument. The returned value should be the same as the returned value of protected <code>match</code> method.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchAccuracy() throws Exception {
        // MockFileNameMatcher always returns false
        assertFalse("The returned value should be correct.", matcher.match(new File("test_files/small.bin")));

        // The passed argument should be correct.
        assertEquals("The protected method's argument should be correct.", "small.bin", matcher.getMatchArgument());
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(FileNameMatcherTestCase.class);
    }
}




