/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * <p>
 * Tests functionality and error cases of <code>TextFileMatcher</code> class. The constructors are trivil, so the
 * accuracy tests are omitted. The <code>match(File)</code> method is defined in its super class
 * <code>FileCategoryMatcher</code>. The accuracy and error cases of this method is already tested in the test case
 * of that class. Therefore, here only the protected <code>match</code> method is tested.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 1.0
 */
public class TextFileMatcherTestCase extends TestCase {
    /** Represents the <code>TextFileMatcher</code> instance used in tests. */
    private TextFileMatcher matcher;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     */
    protected void setUp() {
        matcher = new TextFileMatcher();
    }

    /**
     * <p>
     * Cleans up the test environment. The test instance is disposed.
     * </p>
     */
    protected void tearDown() {
        matcher = null;
    }

    /**
     * <p>
     * Tests constructor <code>TextFileMatcher(Property)</code> when the given property is <code>null</code>. Expect
     * NullPointerException.
     * </p>
     */
    public void testTextFileMatcherPropertyNull() {
        try {
            new TextFileMatcher(null);
            fail("The property is null, should throw NullPointerException.");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests accuracy of <code>match(boolean)</code>. The matcher should match the file when the argument is
     * <code>false</code>, and not match the file when the argument is <code>true</code>.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchAccuracy() throws Exception {
        assertFalse("When file binary flag is true, it does not match the binary file.", matcher.match(true));
        assertTrue("When file binary flag is false, it matches the text file.", matcher.match(false));
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(TextFileMatcherTestCase.class);
    }
}




